@@ -5,6 +5,7 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
   for module_name in \
     puppetlabs-apache \
     puppet-aodh \
+    puppet-auditd \
     puppet-barbican \
     puppet-cassandra \
     puppet-ceph \
@@ -13,6 +14,7 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-certmonger \
     puppet-cinder \
     puppet-common \
+    puppet-congress \
     puppet-contrail \
     puppetlabs-concat \
     puppet-datacat \
@@ -37,15 +39,20 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppetlabs-mongodb \
     puppetlabs-mysql \
     puppet-neutron \
+    puppet-octavia \
     puppet-nova \
     puppet-oslo \
     puppet-nssdb \
+    puppet-opendaylight \
     puppet-ovn \
+    puppet-panko \
     puppet-puppet \
+    puppet-qdr \
     puppetlabs-rabbitmq \
     puppet-redis \
     puppetlabs-rsync \
     puppet-sahara \
+    puppet-tacker \
     puppet-trove \
     puppet-ssh \
     puppet-staging \
@@ -66,6 +73,7 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-snmp \
     puppet-tripleo \
     puppet-ironic \
+    puppet-ipaclient \
     puppet-openstack_extras \
     puppet_aviator \
     puppetlabs-corosync \
@@ -74,7 +82,9 @@ if [ "$DIB_INSTALLTYPE_puppet_modules" = "source" ]; then
     puppet-uchiwa \
     sensu-puppet \
     puppet-kmod \
-    puppet-zaqar; do
+    puppet-etcd \
+    puppet-zaqar \
+    puppet-veritas_hyperscale; do
     export DIB_INSTALLTYPE_${module_name//\-/_}='source'
   done
 fi
